from bluer_options.env import load_config, load_env, get_env

load_env(__name__)
load_config(__name__)

BLUER_AGENT_MACHINE_USER_NAME = get_env("BLUER_AGENT_MACHINE_USER_NAME")

BLUER_AGENT_API_KEY = get_env("BLUER_AGENT_API_KEY")

BLUER_AGENT_TRANSCRIPTION_ENDPOINT = get_env("BLUER_AGENT_TRANSCRIPTION_ENDPOINT")
BLUER_AGENT_TRANSCRIPTION_TEST_OBJECT = get_env("BLUER_AGENT_TRANSCRIPTION_TEST_OBJECT")

BLUER_AGENT_CHAT_ENDPOINT = get_env("BLUER_AGENT_CHAT_ENDPOINT")
BLUER_AGENT_CHAT_TEST_OBJECT = get_env("BLUER_AGENT_CHAT_TEST_OBJECT")

BLUER_AGENT_TRANSCRIPTION_RETRIAL = get_env("BLUER_AGENT_TRANSCRIPTION_RETRIAL", 5)

BLUER_AGENT_AUDIO_TEST_OBJECT = get_env("BLUER_AGENT_AUDIO_TEST_OBJECT")
