from bluer_objects import README

items = README.Items(
    [
        {
            "name": "chat",
            "marquee": "https://github.com/kamangir/assets2/raw/main/bluer-agent/icon.jpg?raw=true",
            "url": "./bluer_agent/docs/chat",
        },
        {
            "name": "transcription",
            "marquee": "https://github.com/kamangir/assets2/raw/main/bluer-agent/icon.jpg?raw=true",
            "url": "./bluer_agent/docs/transcription",
        },
    ]
)
